<!--
If you have encountered a problem while using icclim or you would like to suggest a change,
please follow the structure below to describe your request.
-->

* icclim version:
<!-- import icclim; print(icclim.__version__) -->
* Python version:
<!-- import sys; print(sys.version) -->

### Description
<!--
Describe your issue or the feature requested.
Mandatory.
-->

### Minimal reproducible example
<!--
In case of a bug, please fill this with the code producing the bug.
Optional for feature request or question.
-->

### Output received
<!--
If the code produces an error, please put here the full stack-trace.
Optional for feature request or question.
-->
